==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/conjugate_cc_impl.cc <==
/* -*- c++ -*- */
/*
 * Copyright 2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "conjugate_cc_impl.h"
#include <gr_io_signature.h>
#include <volk/volk.h>

namespace gr {
  namespace blocks {

    conjugate_cc::sptr conjugate_cc::make()
    {
      return gnuradio::get_initial_sptr(new conjugate_cc_impl());
    }

    conjugate_cc_impl::conjugate_cc_impl()
      : gr_sync_block("conjugate_cc",
		      gr_make_io_signature (1, 1, sizeof(gr_complex)),
		      gr_make_io_signature (1, 1, sizeof(gr_complex)))
    {
      const int alignment_multiple =
	volk_get_alignment() / sizeof(gr_complex);
      set_alignment(std::max(1, alignment_multiple));
    }

    int
    conjugate_cc_impl::work(int noutput_items,
			    gr_vector_const_void_star &input_items,
			    gr_vector_void_star &output_items)
    {
      gr_complex *iptr = (gr_complex *) input_items[0];
      gr_complex *optr = (gr_complex *) output_items[0];
      
      if(is_unaligned()) {
	volk_32fc_conjugate_32fc_u(optr, iptr, noutput_items);
      }
      else {
	volk_32fc_conjugate_32fc_a(optr, iptr, noutput_items);
      }
      
      return noutput_items;
    }

  } /* namespace blocks */
}/* namespace gr */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/conjugate_cc_impl.cc <==
/* -*- c++ -*- */
/*
 * Copyright 2012 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "conjugate_cc_impl.h"
#include <gnuradio/io_signature.h>
#include <volk/volk.h>

namespace gr {
  namespace blocks {

    conjugate_cc::sptr conjugate_cc::make()
    {
      return gnuradio::get_initial_sptr(new conjugate_cc_impl());
    }

    conjugate_cc_impl::conjugate_cc_impl()
      : sync_block("conjugate_cc",
		      io_signature::make (1, 1, sizeof(gr_complex)),
		      io_signature::make (1, 1, sizeof(gr_complex)))
    {
      const int alignment_multiple =
	volk_get_alignment() / sizeof(gr_complex);
      set_alignment(std::max(1, alignment_multiple));
    }

    int
    conjugate_cc_impl::work(int noutput_items,
			    gr_vector_const_void_star &input_items,
			    gr_vector_void_star &output_items)
    {
      gr_complex *iptr = (gr_complex *) input_items[0];
      gr_complex *optr = (gr_complex *) output_items[0];
      
      if(is_unaligned()) {
	volk_32fc_conjugate_32fc_u(optr, iptr, noutput_items);
      }
      else {
	volk_32fc_conjugate_32fc_a(optr, iptr, noutput_items);
      }
      
      return noutput_items;
    }

  } /* namespace blocks */
}/* namespace gr */
